==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/iot/kotlin/inputs/TopicRuleErrorActionTimestreamArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.iot.kotlin.inputs

import com.pulumi.aws.iot.inputs.TopicRuleErrorActionTimestreamArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property databaseName The name of an Amazon Timestream database.
 * @property dimensions Configuration blocks with metadata attributes of the time series that are written in each measure record. Nested arguments below.
 * @property roleArn The ARN of the role that grants permission to write to the Amazon Timestream database table.
 * @property tableName The name of the database table into which to write the measure records.
 * @property timestamp Configuration block specifying an application-defined value to replace the default value assigned to the Timestream record's timestamp in the time column. Nested arguments below.
 */
public data class TopicRuleErrorActionTimestreamArgs(
    public val databaseName: Output<String>,
    public val dimensions: Output<List<TopicRuleErrorActionTimestreamDimensionArgs>>,
    public val roleArn: Output<String>,
    public val tableName: Output<String>,
    public val timestamp: Output<TopicRuleErrorActionTimestreamTimestampArgs>? = null,
) : ConvertibleToJava<com.pulumi.aws.iot.inputs.TopicRuleErrorActionTimestreamArgs> {
    override fun toJava(): com.pulumi.aws.iot.inputs.TopicRuleErrorActionTimestreamArgs =
        com.pulumi.aws.iot.inputs.TopicRuleErrorActionTimestreamArgs.builder()
            .databaseName(databaseName.applyValue({ args0 -> args0 }))
            .dimensions(
                dimensions.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .roleArn(roleArn.applyValue({ args0 -> args0 }))
            .tableName(tableName.applyValue({ args0 -> args0 }))
            .timestamp(timestamp?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [TopicRuleErrorActionTimestreamArgs].
 */
@PulumiTagMarker
public class TopicRuleErrorActionTimestreamArgsBuilder internal constructor() {
    private var databaseName: Output<String>? = null

    private var dimensions: Output<List<TopicRuleErrorActionTimestreamDimensionArgs>>? = null

    private var roleArn: Output<String>? = null

    private var tableName: Output<String>? = null

    private var timestamp: Output<TopicRuleErrorActionTimestreamTimestampArgs>? = null

    /**
     * @param value The name of an Amazon Timestream database.
     */
    @JvmName("olwqtpcrihcsxrrf")
    public suspend fun databaseName(`value`: Output<String>) {
        this.databaseName = value
    }

    /**
     * @param value Configuration blocks with metadata attributes of the time series that are written in each measure record. Nested arguments below.
     */
    @JvmName("fvywafhqgidksewd")
    public suspend
    fun dimensions(`value`: Output<List<TopicRuleErrorActionTimestreamDimensionArgs>>) {
        this.dimensions = value
    }

    @JvmName("ufpvnibjilhdvomq")
    public suspend fun dimensions(
        vararg
        values: Output<TopicRuleErrorActionTimestreamDimensionArgs>,
    ) {
        this.dimensions = Output.all(values.asList())
    }

    /**
     * @param values Configuration blocks with metadata attributes of the time series that are written in each measure record. Nested arguments below.
     */
    @JvmName("irrxlkpcwrpvlpre")
    public suspend fun dimensions(values: List<Output<TopicRuleErrorActionTimestreamDimensionArgs>>) {
        this.dimensions = Output.all(values)
    }

    /**
     * @param value The ARN of the role that grants permission to write to the Amazon Timestream database table.
     */
    @JvmName("nrfnpjlrkmyecymn")
    public suspend fun roleArn(`value`: Output<String>) {
        this.roleArn = value
    }

    /**
     * @param value The name of the database table into which to write the measure records.
     */
    @JvmName("dalmlxwrxsoxxojh")
    public suspend fun tableName(`value`: Output<String>) {
        this.tableName = value
    }

    /**
     * @param value Configuration block specifying an application-defined value to replace the default value assigned to the Timestream record's timestamp in the time column. Nested arguments below.
     */
    @JvmName("dfohswwgtajmxslg")
    public suspend fun timestamp(`value`: Output<TopicRuleErrorActionTimestreamTimestampArgs>) {
        this.timestamp = value
    }

    /**
     * @param value The name of an Amazon Timestream database.
     */
    @JvmName("lpjjdhbbkmembubc")
    public suspend fun databaseName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.databaseName = mapped
    }

    /**
     * @param value Configuration blocks with metadata attributes of the time series that are written in each measure record. Nested arguments below.
     */
    @JvmName("yqkpkpcvtfiiysrn")
    public suspend fun dimensions(`value`: List<TopicRuleErrorActionTimestreamDimensionArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dimensions = mapped
    }

    /**
     * @param argument Configuration blocks with metadata attributes of the time series that are written in each measure record. Nested arguments below.
     */
    @JvmName("rfhjlxvifsgfjibw")
    public suspend
    fun dimensions(argument: List<suspend TopicRuleErrorActionTimestreamDimensionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TopicRuleErrorActionTimestreamDimensionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.dimensions = mapped
    }

    /**
     * @param argument Configuration blocks with metadata attributes of the time series that are written in each measure record. Nested arguments below.
     */
    @JvmName("uxpdqtlhuoagdbjg")
    public suspend fun dimensions(
        vararg
        argument: suspend TopicRuleErrorActionTimestreamDimensionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            TopicRuleErrorActionTimestreamDimensionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.dimensions = mapped
    }

    /**
     * @param argument Configuration blocks with metadata attributes of the time series that are written in each measure record. Nested arguments below.
     */
    @JvmName("vdsthmripjwkvimt")
    public suspend
    fun dimensions(argument: suspend TopicRuleErrorActionTimestreamDimensionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            TopicRuleErrorActionTimestreamDimensionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.dimensions = mapped
    }

    /**
     * @param values Configuration blocks with metadata attributes of the time series that are written in each measure record. Nested arguments below.
     */
    @JvmName("klqwuigubtldghcp")
    public suspend fun dimensions(vararg values: TopicRuleErrorActionTimestreamDimensionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dimensions = mapped
    }

    /**
     * @param value The ARN of the role that grants permission to write to the Amazon Timestream database table.
     */
    @JvmName("yrpnovncmpjvyiff")
    public suspend fun roleArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roleArn = mapped
    }

    /**
     * @param value The name of the database table into which to write the measure records.
     */
    @JvmName("aiayreaymtdgkqcw")
    public suspend fun tableName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tableName = mapped
    }

    /**
     * @param value Configuration block specifying an application-defined value to replace the default value assigned to the Timestream record's timestamp in the time column. Nested arguments below.
     */
    @JvmName("bkpidmprxkkcwbwp")
    public suspend fun timestamp(`value`: TopicRuleErrorActionTimestreamTimestampArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timestamp = mapped
    }

    /**
     * @param argument Configuration block specifying an application-defined value to replace the default value assigned to the Timestream record's timestamp in the time column. Nested arguments below.
     */
    @JvmName("gwgdvovepglecimm")
    public suspend
    fun timestamp(argument: suspend TopicRuleErrorActionTimestreamTimestampArgsBuilder.() -> Unit) {
        val toBeMapped = TopicRuleErrorActionTimestreamTimestampArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.timestamp = mapped
    }

    internal fun build(): TopicRuleErrorActionTimestreamArgs = TopicRuleErrorActionTimestreamArgs(
        databaseName = databaseName ?: throw PulumiNullFieldException("databaseName"),
        dimensions = dimensions ?: throw PulumiNullFieldException("dimensions"),
        roleArn = roleArn ?: throw PulumiNullFieldException("roleArn"),
        tableName = tableName ?: throw PulumiNullFieldException("tableName"),
        timestamp = timestamp,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/iot/kotlin/inputs/TopicRuleErrorActionTimestreamArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.iot.kotlin.inputs

import com.pulumi.aws.iot.inputs.TopicRuleErrorActionTimestreamArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property databaseName The name of an Amazon Timestream database.
 * @property dimensions Configuration blocks with metadata attributes of the time series that are written in each measure record. Nested arguments below.
 * @property roleArn The ARN of the role that grants permission to write to the Amazon Timestream database table.
 * @property tableName The name of the database table into which to write the measure records.
 * @property timestamp Configuration block specifying an application-defined value to replace the default value assigned to the Timestream record's timestamp in the time column. Nested arguments below.
 */
public data class TopicRuleErrorActionTimestreamArgs(
    public val databaseName: Output<String>,
    public val dimensions: Output<List<TopicRuleErrorActionTimestreamDimensionArgs>>,
    public val roleArn: Output<String>,
    public val tableName: Output<String>,
    public val timestamp: Output<TopicRuleErrorActionTimestreamTimestampArgs>? = null,
) : ConvertibleToJava<com.pulumi.aws.iot.inputs.TopicRuleErrorActionTimestreamArgs> {
    override fun toJava(): com.pulumi.aws.iot.inputs.TopicRuleErrorActionTimestreamArgs =
        com.pulumi.aws.iot.inputs.TopicRuleErrorActionTimestreamArgs.builder()
            .databaseName(databaseName.applyValue({ args0 -> args0 }))
            .dimensions(
                dimensions.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .roleArn(roleArn.applyValue({ args0 -> args0 }))
            .tableName(tableName.applyValue({ args0 -> args0 }))
            .timestamp(timestamp?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [TopicRuleErrorActionTimestreamArgs].
 */
@PulumiTagMarker
public class TopicRuleErrorActionTimestreamArgsBuilder internal constructor() {
    private var databaseName: Output<String>? = null

    private var dimensions: Output<List<TopicRuleErrorActionTimestreamDimensionArgs>>? = null

    private var roleArn: Output<String>? = null

    private var tableName: Output<String>? = null

    private var timestamp: Output<TopicRuleErrorActionTimestreamTimestampArgs>? = null

    /**
     * @param value The name of an Amazon Timestream database.
     */
    @JvmName("ocuexgspsolulrdp")
    public suspend fun databaseName(`value`: Output<String>) {
        this.databaseName = value
    }

    /**
     * @param value Configuration blocks with metadata attributes of the time series that are written in each measure record. Nested arguments below.
     */
    @JvmName("jloltlysfdfwommh")
    public suspend fun dimensions(`value`: Output<List<TopicRuleErrorActionTimestreamDimensionArgs>>) {
        this.dimensions = value
    }

    @JvmName("agixkvwkkxriigov")
    public suspend fun dimensions(vararg values: Output<TopicRuleErrorActionTimestreamDimensionArgs>) {
        this.dimensions = Output.all(values.asList())
    }

    /**
     * @param values Configuration blocks with metadata attributes of the time series that are written in each measure record. Nested arguments below.
     */
    @JvmName("lgrdvugfjqhgjakk")
    public suspend fun dimensions(values: List<Output<TopicRuleErrorActionTimestreamDimensionArgs>>) {
        this.dimensions = Output.all(values)
    }

    /**
     * @param value The ARN of the role that grants permission to write to the Amazon Timestream database table.
     */
    @JvmName("rskumnusayhglbjn")
    public suspend fun roleArn(`value`: Output<String>) {
        this.roleArn = value
    }

    /**
     * @param value The name of the database table into which to write the measure records.
     */
    @JvmName("eaoepdoogjobxaow")
    public suspend fun tableName(`value`: Output<String>) {
        this.tableName = value
    }

    /**
     * @param value Configuration block specifying an application-defined value to replace the default value assigned to the Timestream record's timestamp in the time column. Nested arguments below.
     */
    @JvmName("rpaceefmlodsubwn")
    public suspend fun timestamp(`value`: Output<TopicRuleErrorActionTimestreamTimestampArgs>) {
        this.timestamp = value
    }

    /**
     * @param value The name of an Amazon Timestream database.
     */
    @JvmName("ruabakdksvlyepyj")
    public suspend fun databaseName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.databaseName = mapped
    }

    /**
     * @param value Configuration blocks with metadata attributes of the time series that are written in each measure record. Nested arguments below.
     */
    @JvmName("bcqqkgnudsjurxph")
    public suspend fun dimensions(`value`: List<TopicRuleErrorActionTimestreamDimensionArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dimensions = mapped
    }

    /**
     * @param argument Configuration blocks with metadata attributes of the time series that are written in each measure record. Nested arguments below.
     */
    @JvmName("gggntxyianjshmyi")
    public suspend fun dimensions(argument: List<suspend TopicRuleErrorActionTimestreamDimensionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TopicRuleErrorActionTimestreamDimensionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.dimensions = mapped
    }

    /**
     * @param argument Configuration blocks with metadata attributes of the time series that are written in each measure record. Nested arguments below.
     */
    @JvmName("rhebbinffsgpduun")
    public suspend fun dimensions(vararg argument: suspend TopicRuleErrorActionTimestreamDimensionArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            TopicRuleErrorActionTimestreamDimensionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.dimensions = mapped
    }

    /**
     * @param argument Configuration blocks with metadata attributes of the time series that are written in each measure record. Nested arguments below.
     */
    @JvmName("thmmrmylfjgwewrn")
    public suspend fun dimensions(argument: suspend TopicRuleErrorActionTimestreamDimensionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            TopicRuleErrorActionTimestreamDimensionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.dimensions = mapped
    }

    /**
     * @param values Configuration blocks with metadata attributes of the time series that are written in each measure record. Nested arguments below.
     */
    @JvmName("dobufljmriqmmrvj")
    public suspend fun dimensions(vararg values: TopicRuleErrorActionTimestreamDimensionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dimensions = mapped
    }

    /**
     * @param value The ARN of the role that grants permission to write to the Amazon Timestream database table.
     */
    @JvmName("bkaflctlonljdjsa")
    public suspend fun roleArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roleArn = mapped
    }

    /**
     * @param value The name of the database table into which to write the measure records.
     */
    @JvmName("jlycyahieeeopthp")
    public suspend fun tableName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tableName = mapped
    }

    /**
     * @param value Configuration block specifying an application-defined value to replace the default value assigned to the Timestream record's timestamp in the time column. Nested arguments below.
     */
    @JvmName("fjuaafliwmwurmxy")
    public suspend fun timestamp(`value`: TopicRuleErrorActionTimestreamTimestampArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timestamp = mapped
    }

    /**
     * @param argument Configuration block specifying an application-defined value to replace the default value assigned to the Timestream record's timestamp in the time column. Nested arguments below.
     */
    @JvmName("vcocrymijjroqdvs")
    public suspend fun timestamp(argument: suspend TopicRuleErrorActionTimestreamTimestampArgsBuilder.() -> Unit) {
        val toBeMapped = TopicRuleErrorActionTimestreamTimestampArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.timestamp = mapped
    }

    internal fun build(): TopicRuleErrorActionTimestreamArgs = TopicRuleErrorActionTimestreamArgs(
        databaseName = databaseName ?: throw PulumiNullFieldException("databaseName"),
        dimensions = dimensions ?: throw PulumiNullFieldException("dimensions"),
        roleArn = roleArn ?: throw PulumiNullFieldException("roleArn"),
        tableName = tableName ?: throw PulumiNullFieldException("tableName"),
        timestamp = timestamp,
    )
}
